@@ -8,7 +8,7 @@ context("Correct Seed")
 
 test_that("correct random seed is used", {
   N      <- sample(seq(2, 50, 2), 1)           # Sample number of patients
-  r      <- sample(30, 1)                      # Sample number of randomisation sequences
+  r      <- sample(30, 1)                      # Sample number of randomization sequences
   mti    <- sample(N/2, 1)                     # Sample maximum tolerated imbalance
   p      <- sample(seq(0.5001, 1, 0.05), 1)    # biased coin parameter
   seed   <- sample(1000, 1)                    # Sample seed
